 .onLoad <- function(lib,pkg)
{
  library.dynam("RSKC",pkg,lib)
}
